@@ -128,8 +128,6 @@ def read_project_markdown(file):
                 start_desc = False
                 start_project = True
 
-    print(desc)
-    print(project)
     return "\n".join(desc), project[0].strip().replace("<", "").replace(">", "")
 
 
@@ -471,7 +469,7 @@ class TreeWalker:
             try:
                 if meta["type"] == "code_options":
                     doc = parse(state)
-                else:
+                elif meta["type"] == "inscode_project":
                     walk_project_2_config(self.root)
             except ParsecError as err:
                 index = state.index
